==> udp-0.4.5-py2-none-any.whl: udp/__init__.py <==
# -*- coding: utf-8 -*-
#
#   UDP: User Datagram Protocol
#
#                                Written in 2020 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2020 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

from .net import Channel
from .net import Connection, ConnectionDelegate
from .net import ConnectionState, ConnectionStateMachine
from .net import Hub, BaseHub
from .net import BaseConnection, ActiveConnection

from .net import PackageConnection, ActivePackageConnection

from .channel import DiscreteChannel
from .hub import PackageHub, ActivePackageHub

name = "UDP"

__author__ = 'Albert Moky'

__all__ = [

    #
    #   Net
    #
    'Channel',
    'Connection', 'ConnectionDelegate',
    'ConnectionState', 'ConnectionStateMachine',
    'Hub', 'BaseHub',
    'BaseConnection', 'ActiveConnection',

    'PackageConnection', 'ActivePackageConnection',

    #
    #   Discrete
    #
    'DiscreteChannel',
    'PackageHub', 'ActivePackageHub',
]

==> udp-0.4.6-py2-none-any.whl: udp/__init__.py <==
# -*- coding: utf-8 -*-
#
#   UDP: User Datagram Protocol
#
#                                Written in 2020 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2020 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

from .net import Hub, Channel, Connection, ConnectionDelegate
from .net import ConnectionState, ConnectionStateMachine
from .net import BaseHub, BaseChannel, BaseConnection, ActiveConnection

from .net import PackageConnection, ActivePackageConnection

from .channel import DiscreteChannel
from .hub import PackageHub, ActivePackageHub

name = "UDP"

__author__ = 'Albert Moky'

__all__ = [

    #
    #   Net
    #
    'Hub', 'Channel', 'Connection', 'ConnectionDelegate',
    'ConnectionState', 'ConnectionStateMachine',
    'BaseHub', 'BaseChannel', 'BaseConnection', 'ActiveConnection',

    'PackageConnection', 'ActivePackageConnection',

    #
    #   Discrete
    #
    'DiscreteChannel',
    'PackageHub', 'ActivePackageHub',
]
